@@ -19,20 +19,25 @@ import unforward
 import fileinput
 import json
 import sys
+from unforward.errors import NoForwardFoundError
+from unforward.errors import ExtractionError
 
 def main():
     """ The main starting point for the unforward script."""
     extractor = unforward.Extractor()
-    
-    if '--html' in sys.argv:
-        sys.argv.remove('--html')
-        email_text = ''.join(line for line in fileinput.input())
-        result = extractor.extract_from_html(email_text)
-    else:    
-        email_text = ''.join(line for line in fileinput.input())
-        result = extractor.extract(email_text)
-    
-    print(json.dumps(result))
+    try:
+        if '--html' in sys.argv:
+            sys.argv.remove('--html')
+            email_text = ''.join(line for line in fileinput.input())
+            result = extractor.extract_from_html(email_text)
+        else:    
+            email_text = ''.join(line for line in fileinput.input())
+            result = extractor.extract(email_text)
+        print(json.dumps(result))
+    except ExtractionError as e:
+        exit(2)
+    except NoForwardFoundError as e:
+        exit(1)
     
 
 
